@@ -17,21 +17,27 @@ var out = drive.createArchive({file: name => raf('out/' + name)})
 console.log(process.memoryUsage().rss)
 
 // define transforms
-RDD(archive)
+var rdd = RDD(archive)
   .select(x => x.name === 'uber-raw-data-jul14.csv' || x.name === 'uber-raw-data-jun14.csv')
   .csv()
-  .map(x => [x['Base'], JSON.stringify(x)])
-  .partitionByKey('out').then(x => {
-    console.log(process.memoryUsage().rss)
-    process.exit()
-  })
+//.map(x => [x['Base'], JSON.stringify(x)])
+
+rdd
   /*
+  .partitionByKey(out).then(x => {
+    var ws = out.createFileWriteStream('index.html')
+    ws.write(`${JSON.stringify(rdd.marshal())}`)
+    ws.end()
+    console.log(process.memoryUsage().rss)
+    swarm(out)
+    console.log(out.key.toString('hex'))
+    // process.exit()
+  })
+  */
   .map(row => kv(row['Base'], 1))
   .reduceByKey((x, y) => x + y).toArray(res => {
     console.log(res)
     console.log(process.memoryUsage().rss)
     process.exit()
   })
-  */
 // .partition(row => {return row['DateTime']}, out).then(() => {console.log('ok')})
-
